from typing import Any, Optional
from fastapi import status


class BaseException(Exception):
    """自定义异常基类"""

    def __init__(self,
                 code: int = status.HTTP_500_INTERNAL_SERVER_ERROR,
                 message: str = "Internal Server Error",
                 detail: Optional[Any] = None):
        self.code = code
        self.message = message
        self.detail = detail
        super().__init__(message)

    def __str__(self):
        return f"{self.__class__.__name__}(code={self.code}, message={self.message}, detail={self.detail})"

    def to_dict(self):
        """将异常转换为字典格式"""
        return {
            "code": self.code,
            "message": self.message,
            "detail": self.detail
        }
