from fastapi import APIRouter, Depends, HTTPException
from fastapi.security import OAuth2PasswordRequestForm
from sqlalchemy.orm import Session
from ..services.auth_service import AuthService
from ..models.auth_models import Token
from ..middleware.auth_middleware import get_current_user
from ..database import get_db

router = APIRouter(prefix="/auth", tags=["Authentication"])


@router.post("/login", response_model=Token)
async def login(form_data: OAuth2PasswordRequestForm = Depends(),
                db: Session = Depends(get_db)):
    token = await AuthService.login(db, form_data.username, form_data.password)
    if not token:
        raise HTTPException(status_code=401,
                            detail="Incorrect username or password")
    return token


@router.post("/refresh", response_model=Token)
async def refresh_token(refresh_token: str, db: Session = Depends(get_db)):
    try:
        token = await AuthService.refresh_token(db, refresh_token)
        if not token:
            raise HTTPException(status_code=401,
                                detail="Invalid refresh token")
        return token
    except ValueError as e:
        raise HTTPException(status_code=500, detail=str(e))
    except Exception as e:
        raise HTTPException(status_code=500, detail="Internal server error")


@router.get("/me")
async def get_current_user_info(
        current_user: dict = Depends(get_current_user)):
    return current_user
