from typing import Any
from fastapi import status
from ..common.exceptions import BaseException
from ..common.constants import ErrorCode


class APIException(BaseException):
    """API异常基类"""

    def __init__(self,
                 code: int = ErrorCode.UNKNOWN_ERROR,
                 message: str = "API Error",
                 detail: Any = None,
                 http_status: int = status.HTTP_400_BAD_REQUEST):
        super().__init__(code=code, message=message, detail=detail)
        self.http_status = http_status

    def to_dict(self):
        """将异常转换为API响应格式"""
        return {
            "error": {
                "code": self.code,
                "message": self.message,
                "detail": self.detail
            }
        }
