from fastapi import Request, Response
from fastapi.responses import JSONResponse
from starlette.middleware.base import BaseHTTPMiddleware
from typing import Optional, Dict, Any
import logging

from ..exception.api_exception import APIException
from ..exception.business_exception import BusinessException
from ..common.constants import ErrorCode

logger = logging.getLogger(__name__)


class ExceptionHandlerMiddleware(BaseHTTPMiddleware):

    async def dispatch(self, request: Request, call_next):
        try:
            response = await call_next(request)
            return response
        except BusinessException as e:
            logger.warning(f"Business Exception: {str(e)}")
            return JSONResponse(status_code=e.http_status,
                                content={
                                    "error": {
                                        "code": e.code,
                                        "message": e.message,
                                        "detail": e.detail
                                    }
                                })
        except APIException as e:
            logger.error(f"API Exception: {str(e)}")
            return JSONResponse(status_code=e.http_status,
                                content={
                                    "error": {
                                        "code": e.code,
                                        "message": e.message,
                                        "detail": e.detail
                                    }
                                })
        except Exception as e:
            logger.exception(f"Unexpected Exception: {str(e)}")
            return JSONResponse(status_code=500,
                                content={
                                    "error": {
                                        "code": ErrorCode.UNKNOWN_ERROR,
                                        "message": "Internal Server Error",
                                        "detail": str(e)
                                    }
                                })
