from ..models.base_model import BaseModel, CreateModel
from ..database import db
from sqlalchemy import JSON


class ExamPaper(CreateModel):
    __tablename__ = 'exam_papers'

    id = db.Column(db.Integer, primary_key=True)
    name = db.Column(db.String(100), nullable=False)
    description = db.Column(db.Text)
    duration = db.Column(db.Integer)  # 考试时长（分钟）
    total_score = db.Column(db.Float)
    difficulty = db.Column(db.String(20))
    status = db.Column(db.String(20), default='draft')
    tags = db.Column(JSON)
    creator_id = db.Column(db.Integer, db.ForeignKey('users.id'))
    create_time = db.Column(db.DateTime, default=db.func.now())
    update_time = db.Column(db.DateTime, onupdate=db.func.now())

    # 关系定义
    creator = db.relationship('User', foreign_keys=[creator_id])
    questions = db.relationship('Question', secondary='exam_paper_questions')
    exam_records = db.relationship('ExamRecord', backref='exam_paper')

    def __repr__(self):
        return f'<ExamPaper {self.id}: {self.name}>'
